dupin.preprocessing.filter
--------------------------

.. py:currentmodule:: dupin.preprocessing.filter

.. autosummary::
    :nosignatures:

    Correlated
    MeanShift
    jump_size_importance
    local_smoothness_importance
    mean_shift_importance
    noise_importance

.. rubric:: Details

.. automodule:: dupin.preprocessing.filter
    :synopsis: Methods and classes for feature selection.
    :members: Correlated,
              MeanShift,
              jump_size_importance,
              local_smoothness_importance,
              mean_shift_importance,
              noise_importance
